aboutsummaryrefslogtreecommitdiffstats
path: root/client.c
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--client.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/client.c b/client.c
index e88b7d4..09966c3 100644
--- a/client.c
+++ b/client.c
@@ -15,7 +15,7 @@
* ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
* OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*
- * $OpenBSD: client.c,v 1.92 2012/05/13 15:15:54 okan Exp $
+ * $OpenBSD: client.c,v 1.93 2012/05/13 15:17:13 okan Exp $
*/
#include <sys/param.h>
@@ -228,7 +228,7 @@ client_setactive(struct client_ctx *cc, int fg)
* If we're in the middle of alt-tabbing, don't change
* the order please.
*/
- if (!sc->altpersist)
+ if (!sc->cycling)
client_mtf(cc);
} else
client_leave(cc);
@@ -638,8 +638,8 @@ client_cycle(struct screen_ctx *sc, int flags)
}
}
- /* reset when alt is released. XXX I hate this hack */
- sc->altpersist = 1;
+ /* reset when cycling mod is released. XXX I hate this hack */
+ sc->cycling = 1;
client_ptrsave(oldcc);
client_ptrwarp(newcc);
}